Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorHenrik Rentz-Reichert2011-09-22 07:47:43 +0000
committerHenrik Rentz-Reichert2011-09-22 07:47:43 +0000
commit73a4e87ad245abfe07afbb5e75b4819960137bf0 (patch)
treebbe0390887a8de15e4a4b0d273a5601dfe988a6f
parent4397ae0b1b86174c23c6df1742eccd65231d7a70 (diff)
downloadorg.eclipse.etrice-73a4e87ad245abfe07afbb5e75b4819960137bf0.tar.gz
org.eclipse.etrice-73a4e87ad245abfe07afbb5e75b4819960137bf0.tar.xz
org.eclipse.etrice-73a4e87ad245abfe07afbb5e75b4819960137bf0.zip
[integration.tests] added new and deleted old files
-rw-r--r--tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/MrPingActor.java8
-rw-r--r--tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPong.java211
-rw-r--r--tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPort.java211
-rw-r--r--tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPortRunner.java (renamed from tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongRunner.java)8
4 files changed, 222 insertions, 216 deletions
diff --git a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/MrPingActor.java b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/MrPingActor.java
index 2a2e7dce8..2a4b69ff7 100644
--- a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/MrPingActor.java
+++ b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/MrPingActor.java
@@ -250,8 +250,14 @@ public class MrPingActor extends ActorClassBase {
if (count++ > 1000) {
RTServices.getInstance().getSubSystem().testFinished(0);
} else {
+ //PingPongPort.get(0).ping();
+ //PingPongPort.get(1).ping();
+ //PingPongPort.get(2).ping();
+ System.out.println(pongCount);
System.out.println(count);
- timer.Start(5);}
+ pongCount = 0;
+ timer.Start(10);
+ }
}
//******************************************
diff --git a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPong.java b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPong.java
deleted file mode 100644
index f05aa7765..000000000
--- a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPong.java
+++ /dev/null
@@ -1,211 +0,0 @@
-package org.eclipse.etrice.integration.PingPongThreadTestReplPort;
-
-import org.eclipse.etrice.runtime.java.messaging.MessageService;
-import org.eclipse.etrice.runtime.java.messaging.RTServices;
-import org.eclipse.etrice.runtime.java.messaging.Address;
-import org.eclipse.etrice.runtime.java.messaging.IRTObject;
-import org.eclipse.etrice.runtime.java.messaging.RTSystemServicesProtocol.*;
-import org.eclipse.etrice.runtime.java.modelbase.ActorClassBase;
-import org.eclipse.etrice.runtime.java.modelbase.SubSystemClassBase;
-import org.eclipse.etrice.runtime.java.modelbase.InterfaceItemBase;
-
-import room.basic.service.timing.*;
-
-
-
-public class SubSystem_PingPong extends SubSystemClassBase{
-
-
- public SubSystem_PingPong(IRTObject parent, String name) {
- super(parent, name);
- }
-
- @Override
- public void receiveEvent(InterfaceItemBase ifitem, int evt, Object data){
- }
-
- @Override
- public void instantiateMessageServices(){
-
- RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 0, 0),"MessageService_Main"));
- RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 1, 0),"MessageService_mrPingThread", 5));
- RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 2, 0),"MessageService_mrPong1Thread", 5));
- RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 3, 0),"MessageService_mrPong2Thread", 5));
- RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 4, 0),"MessageService_mrPong3Thread", 5));
- }
-
- @Override
- public void instantiateActors(){
- // all addresses
- // Addresses for the Subsystem Systemport
- Address addr_item_SystemPort_0 = new Address(0,0,115);
- Address addr_item_SystemPort_1 = new Address(0,0,116);
- Address addr_item_SystemPort_2 = new Address(0,0,117);
- Address addr_item_SystemPort_3 = new Address(0,0,118);
- Address addr_item_SystemPort_4 = new Address(0,0,119);
- Address addr_item_SystemPort_5 = new Address(0,0,120);
-
- // actor instance /SubSystem_PingPong/application itself => Systemport Address
- // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
- Address addr_item__SubSystem_PingPong_application = new Address(0,0,101);
- // interface items of /SubSystem_PingPong/application
- // actor instance /SubSystem_PingPong/application/MrPing itself => Systemport Address
- // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
- Address addr_item__SubSystem_PingPong_application_MrPing = new Address(0,1,102);
- // interface items of /SubSystem_PingPong/application/MrPing
- Address addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_0 = new Address(0,0,103);
- Address addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_1 = new Address(0,0,104);
- Address addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_2 = new Address(0,0,105);
- Address addr_item__SubSystem_PingPong_application_MrPing_timer = new Address(0,1,106);
- // actor instance /SubSystem_PingPong/application/MrPong1 itself => Systemport Address
- // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
- Address addr_item__SubSystem_PingPong_application_MrPong1 = new Address(0,2,107);
- // interface items of /SubSystem_PingPong/application/MrPong1
- Address addr_item__SubSystem_PingPong_application_MrPong1_PingPongPort = new Address(0,2,108);
- // actor instance /SubSystem_PingPong/application/MrPong2 itself => Systemport Address
- // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
- Address addr_item__SubSystem_PingPong_application_MrPong2 = new Address(0,3,109);
- // interface items of /SubSystem_PingPong/application/MrPong2
- Address addr_item__SubSystem_PingPong_application_MrPong2_PingPongPort = new Address(0,3,110);
- // actor instance /SubSystem_PingPong/application/MrPong3 itself => Systemport Address
- // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
- Address addr_item__SubSystem_PingPong_application_MrPong3 = new Address(0,4,111);
- // interface items of /SubSystem_PingPong/application/MrPong3
- Address addr_item__SubSystem_PingPong_application_MrPong3_PingPongPort = new Address(0,4,112);
- // actor instance /SubSystem_PingPong/services itself => Systemport Address
- // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
- Address addr_item__SubSystem_PingPong_services = new Address(0,0,113);
- // interface items of /SubSystem_PingPong/services
- Address addr_item__SubSystem_PingPong_services_timeout_0 = new Address(0,0,114);
-
- // instantiate all actor instances
- instances = new ActorClassBase[6];
- instances[0] = new PingPongTop(
- this,
- "application",
- // own interface item addresses
- new Address[][] {{addr_item__SubSystem_PingPong_application}
- },
- // peer interface item addresses
- new Address[][] {{addr_item_SystemPort_0}
- }
- );
- instances[1] = new MrPingActor(
- instances[0],
- "MrPing",
- // own interface item addresses
- new Address[][] {{addr_item__SubSystem_PingPong_application_MrPing},
- {
- addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_0,
- addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_1,
- addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_2
- },
- {
- addr_item__SubSystem_PingPong_application_MrPing_timer
- }
- },
- // peer interface item addresses
- new Address[][] {{addr_item_SystemPort_1},
- {
- addr_item__SubSystem_PingPong_application_MrPong1_PingPongPort,
- addr_item__SubSystem_PingPong_application_MrPong2_PingPongPort,
- addr_item__SubSystem_PingPong_application_MrPong3_PingPongPort
- },
- {
- addr_item__SubSystem_PingPong_services_timeout_0
- }
- }
- );
- instances[2] = new MrPongActor1(
- instances[0],
- "MrPong1",
- // own interface item addresses
- new Address[][] {{addr_item__SubSystem_PingPong_application_MrPong1},
- {
- addr_item__SubSystem_PingPong_application_MrPong1_PingPongPort
- }
- },
- // peer interface item addresses
- new Address[][] {{addr_item_SystemPort_2},
- {
- addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_0
- }
- }
- );
- instances[3] = new MrPongActor1(
- instances[0],
- "MrPong2",
- // own interface item addresses
- new Address[][] {{addr_item__SubSystem_PingPong_application_MrPong2},
- {
- addr_item__SubSystem_PingPong_application_MrPong2_PingPongPort
- }
- },
- // peer interface item addresses
- new Address[][] {{addr_item_SystemPort_3},
- {
- addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_1
- }
- }
- );
- instances[4] = new MrPongActor1(
- instances[0],
- "MrPong3",
- // own interface item addresses
- new Address[][] {{addr_item__SubSystem_PingPong_application_MrPong3},
- {
- addr_item__SubSystem_PingPong_application_MrPong3_PingPongPort
- }
- },
- // peer interface item addresses
- new Address[][] {{addr_item_SystemPort_4},
- {
- addr_item__SubSystem_PingPong_application_MrPing_PingPongPort_2
- }
- }
- );
- instances[5] = new ATimingService(
- this,
- "services",
- // own interface item addresses
- new Address[][] {{addr_item__SubSystem_PingPong_services},
- {
- },
- {
- addr_item__SubSystem_PingPong_services_timeout_0
- }
- },
- // peer interface item addresses
- new Address[][] {{addr_item_SystemPort_5},
- {
- },
- {
- addr_item__SubSystem_PingPong_application_MrPing_timer
- }
- }
- );
-
- // create the subsystem system port
- RTSystemPort = new RTSystemServicesProtocolConjPortRepl(this, "RTSystemPort",
- 0, //local ID
- // own addresses
- new Address[]{
- addr_item_SystemPort_0,
- addr_item_SystemPort_1,
- addr_item_SystemPort_2,
- addr_item_SystemPort_3,
- addr_item_SystemPort_4,
- addr_item_SystemPort_5
- },
- // peer addresses
- new Address[]{
- addr_item__SubSystem_PingPong_application,
- addr_item__SubSystem_PingPong_application_MrPing,
- addr_item__SubSystem_PingPong_application_MrPong1,
- addr_item__SubSystem_PingPong_application_MrPong2,
- addr_item__SubSystem_PingPong_application_MrPong3,
- addr_item__SubSystem_PingPong_services
- });
-
- }
-};
diff --git a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPort.java b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPort.java
new file mode 100644
index 000000000..0146646cb
--- /dev/null
+++ b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPort.java
@@ -0,0 +1,211 @@
+package org.eclipse.etrice.integration.PingPongThreadTestReplPort;
+
+import org.eclipse.etrice.runtime.java.messaging.MessageService;
+import org.eclipse.etrice.runtime.java.messaging.RTServices;
+import org.eclipse.etrice.runtime.java.messaging.Address;
+import org.eclipse.etrice.runtime.java.messaging.IRTObject;
+import org.eclipse.etrice.runtime.java.messaging.RTSystemServicesProtocol.*;
+import org.eclipse.etrice.runtime.java.modelbase.ActorClassBase;
+import org.eclipse.etrice.runtime.java.modelbase.SubSystemClassBase;
+import org.eclipse.etrice.runtime.java.modelbase.InterfaceItemBase;
+
+import room.basic.service.timing.*;
+
+
+
+public class SubSystem_PingPongReplPort extends SubSystemClassBase{
+
+
+ public SubSystem_PingPongReplPort(IRTObject parent, String name) {
+ super(parent, name);
+ }
+
+ @Override
+ public void receiveEvent(InterfaceItemBase ifitem, int evt, Object data){
+ }
+
+ @Override
+ public void instantiateMessageServices(){
+
+ RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 0, 0),"MessageService_Main"));
+ RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 1, 0),"MessageService_mrPingThread", 5));
+ RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 2, 0),"MessageService_mrPong1Thread", 5));
+ RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 3, 0),"MessageService_mrPong2Thread", 5));
+ RTServices.getInstance().getMsgSvcCtrl().addMsgSvc(new MessageService(this, new Address(0, 4, 0),"MessageService_mrPong3Thread", 5));
+ }
+
+ @Override
+ public void instantiateActors(){
+ // all addresses
+ // Addresses for the Subsystem Systemport
+ Address addr_item_SystemPort_0 = new Address(0,0,115);
+ Address addr_item_SystemPort_1 = new Address(0,0,116);
+ Address addr_item_SystemPort_2 = new Address(0,0,117);
+ Address addr_item_SystemPort_3 = new Address(0,0,118);
+ Address addr_item_SystemPort_4 = new Address(0,0,119);
+ Address addr_item_SystemPort_5 = new Address(0,0,120);
+
+ // actor instance /SubSystem_PingPongReplPort/application itself => Systemport Address
+ // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
+ Address addr_item__SubSystem_PingPongReplPort_application = new Address(0,0,101);
+ // interface items of /SubSystem_PingPongReplPort/application
+ // actor instance /SubSystem_PingPongReplPort/application/MrPing itself => Systemport Address
+ // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPing = new Address(0,1,102);
+ // interface items of /SubSystem_PingPongReplPort/application/MrPing
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_0 = new Address(0,0,103);
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_1 = new Address(0,0,104);
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_2 = new Address(0,0,105);
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPing_timer = new Address(0,1,106);
+ // actor instance /SubSystem_PingPongReplPort/application/MrPong1 itself => Systemport Address
+ // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPong1 = new Address(0,2,107);
+ // interface items of /SubSystem_PingPongReplPort/application/MrPong1
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPong1_PingPongPort = new Address(0,2,108);
+ // actor instance /SubSystem_PingPongReplPort/application/MrPong2 itself => Systemport Address
+ // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPong2 = new Address(0,3,109);
+ // interface items of /SubSystem_PingPongReplPort/application/MrPong2
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPong2_PingPongPort = new Address(0,3,110);
+ // actor instance /SubSystem_PingPongReplPort/application/MrPong3 itself => Systemport Address
+ // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPong3 = new Address(0,4,111);
+ // interface items of /SubSystem_PingPongReplPort/application/MrPong3
+ Address addr_item__SubSystem_PingPongReplPort_application_MrPong3_PingPongPort = new Address(0,4,112);
+ // actor instance /SubSystem_PingPongReplPort/services itself => Systemport Address
+ // TODOTJ: For each Actor, multiple addresses should be generated (actor?, systemport, debugport)
+ Address addr_item__SubSystem_PingPongReplPort_services = new Address(0,0,113);
+ // interface items of /SubSystem_PingPongReplPort/services
+ Address addr_item__SubSystem_PingPongReplPort_services_timeout_0 = new Address(0,0,114);
+
+ // instantiate all actor instances
+ instances = new ActorClassBase[6];
+ instances[0] = new PingPongTop(
+ this,
+ "application",
+ // own interface item addresses
+ new Address[][] {{addr_item__SubSystem_PingPongReplPort_application}
+ },
+ // peer interface item addresses
+ new Address[][] {{addr_item_SystemPort_0}
+ }
+ );
+ instances[1] = new MrPingActor(
+ instances[0],
+ "MrPing",
+ // own interface item addresses
+ new Address[][] {{addr_item__SubSystem_PingPongReplPort_application_MrPing},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_0,
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_1,
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_2
+ },
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_timer
+ }
+ },
+ // peer interface item addresses
+ new Address[][] {{addr_item_SystemPort_1},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPong1_PingPongPort,
+ addr_item__SubSystem_PingPongReplPort_application_MrPong2_PingPongPort,
+ addr_item__SubSystem_PingPongReplPort_application_MrPong3_PingPongPort
+ },
+ {
+ addr_item__SubSystem_PingPongReplPort_services_timeout_0
+ }
+ }
+ );
+ instances[2] = new MrPongActor1(
+ instances[0],
+ "MrPong1",
+ // own interface item addresses
+ new Address[][] {{addr_item__SubSystem_PingPongReplPort_application_MrPong1},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPong1_PingPongPort
+ }
+ },
+ // peer interface item addresses
+ new Address[][] {{addr_item_SystemPort_2},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_0
+ }
+ }
+ );
+ instances[3] = new MrPongActor1(
+ instances[0],
+ "MrPong2",
+ // own interface item addresses
+ new Address[][] {{addr_item__SubSystem_PingPongReplPort_application_MrPong2},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPong2_PingPongPort
+ }
+ },
+ // peer interface item addresses
+ new Address[][] {{addr_item_SystemPort_3},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_1
+ }
+ }
+ );
+ instances[4] = new MrPongActor1(
+ instances[0],
+ "MrPong3",
+ // own interface item addresses
+ new Address[][] {{addr_item__SubSystem_PingPongReplPort_application_MrPong3},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPong3_PingPongPort
+ }
+ },
+ // peer interface item addresses
+ new Address[][] {{addr_item_SystemPort_4},
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_PingPongPort_2
+ }
+ }
+ );
+ instances[5] = new ATimingService(
+ this,
+ "services",
+ // own interface item addresses
+ new Address[][] {{addr_item__SubSystem_PingPongReplPort_services},
+ {
+ },
+ {
+ addr_item__SubSystem_PingPongReplPort_services_timeout_0
+ }
+ },
+ // peer interface item addresses
+ new Address[][] {{addr_item_SystemPort_5},
+ {
+ },
+ {
+ addr_item__SubSystem_PingPongReplPort_application_MrPing_timer
+ }
+ }
+ );
+
+ // create the subsystem system port
+ RTSystemPort = new RTSystemServicesProtocolConjPortRepl(this, "RTSystemPort",
+ 0, //local ID
+ // own addresses
+ new Address[]{
+ addr_item_SystemPort_0,
+ addr_item_SystemPort_1,
+ addr_item_SystemPort_2,
+ addr_item_SystemPort_3,
+ addr_item_SystemPort_4,
+ addr_item_SystemPort_5
+ },
+ // peer addresses
+ new Address[]{
+ addr_item__SubSystem_PingPongReplPort_application,
+ addr_item__SubSystem_PingPongReplPort_application_MrPing,
+ addr_item__SubSystem_PingPongReplPort_application_MrPong1,
+ addr_item__SubSystem_PingPongReplPort_application_MrPong2,
+ addr_item__SubSystem_PingPongReplPort_application_MrPong3,
+ addr_item__SubSystem_PingPongReplPort_services
+ });
+
+ }
+};
diff --git a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongRunner.java b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPortRunner.java
index 5dd28cd7f..3019e0f17 100644
--- a/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongRunner.java
+++ b/tests/org.eclipse.etrice.integration.tests/src-gen/org/eclipse/etrice/integration/PingPongThreadTestReplPort/SubSystem_PingPongReplPortRunner.java
@@ -1,17 +1,17 @@
/**
* @author generated by eTrice
*
* this class contains the main function running component SubSystem_PingPong
* it instantiates SubSystem_PingPong and starts and ends the lifecycle
*/
package org.eclipse.etrice.integration.PingPongThreadTestReplPort;
import org.eclipse.etrice.runtime.java.modelbase.SubSystemRunnerBase;
-class SubSystem_PingPongRunner extends SubSystemRunnerBase {
+class SubSystem_PingPongReplPortRunner extends SubSystemRunnerBase {
- static SubSystem_PingPong main_component = new SubSystem_PingPong(null, "SubSystem_PingPong");
+ static SubSystem_PingPongReplPort main_component = new SubSystem_PingPongReplPort(null, "SubSystem_PingPongReplPort");
/**
* main function
@@ -1,17 +1,17 @@
* @author generated by eTrice
*
- * this class contains the main function running component SubSystem_PingPong
- * it instantiates SubSystem_PingPong and starts and ends the lifecycle
+ * this class contains the main function running component SubSystem_PingPongReplPort
+ * it instantiates SubSystem_PingPongReplPort and starts and ends the lifecycle
*/
package org.eclipse.etrice.integration.PingPongThreadTestReplPort;

Back to the top